@@ -1,12 +1,13 @@
 package SOAP::WSDL::Generator::Template;
 use strict;
 use Template;
-use Class::Std::Storable;
+use Class::Std::Fast::Storable;
 
-our $VERSION='2.00_17';
+our $VERSION=q{2.00_25};
 
 my %tt_of               :ATTR(:get<tt>);
 my %definitions_of      :ATTR(:name<definitions>    :default<()>);
+my %server_prefix_of    :ATTR(:name<server_prefix> :default<MyServer>);
 my %interface_prefix_of :ATTR(:name<interface_prefix> :default<MyInterfaces>);
 my %typemap_prefix_of   :ATTR(:name<typemap_prefix> :default<MyTypemaps>);
 my %type_prefix_of      :ATTR(:name<type_prefix>    :default<MyTypes>);
@@ -23,17 +24,21 @@ sub START {
 sub _process :PROTECTED {
     my ($self, $template, $arg_ref, $output) = @_;
     my $ident = ident $self;
-    my $tt = $tt_of{$ident} ||= Template->new(
+
+    $tt_of{$ident} = Template->new(
         DEBUG => 1,
         EVAL_PERL => $EVAL_PERL_of{ $ident },
         RECURSION => $RECURSION_of{ $ident },
         INCLUDE_PATH => $INCLUDE_PATH_of{ $ident },
         OUTPUT_PATH => $OUTPUT_PATH_of{ $ident },
-    );
-    $tt->process( $template,
+    )
+        if (not $tt_of{ $ident });
+
+    $tt_of{ $ident }->process( $template,
     {
         definitions => $self->get_definitions,
         interface_prefix => $self->get_interface_prefix,
+        server_prefix => $self->get_server_prefix,
         type_prefix => $self->get_type_prefix,
         typemap_prefix => $self->get_typemap_prefix,
         TYPE_PREFIX => $self->get_type_prefix,
@@ -42,7 +47,7 @@ sub _process :PROTECTED {
         %{ $arg_ref }
     },
     $output)
-        or die $INCLUDE_PATH_of{ $ident }, '\\', $template, ' ', $tt->error();
+        or die $INCLUDE_PATH_of{ $ident }, '\\', $template, ' ', $tt_of{ $ident }->error();
 }
 
 1;
\ No newline at end of file
